@@ -53,7 +53,7 @@ AppSettings::AppSettings(QWidget * parent, Qt::WindowFlags f) : QDialog(parent,
     widgetContent->setLayout(vlayout.release());
 
     setWindowTitle(tr("%1 settings").arg(APP_NAME));
-    lblCaption->setText(tr("%1 settings").arg(APP_NAME));
+    setWindowIcon(CoreLib->loadIcon(CoreLib->getSetting("app", "icon", false, "q4wine").toString()));
 
     connect(optionsTree, SIGNAL(itemClicked (QTreeWidgetItem *, int)), this, SLOT(optionsTree_itemClicked ( QTreeWidgetItem *, int)));
 
@@ -89,6 +89,16 @@ AppSettings::AppSettings(QWidget * parent, Qt::WindowFlags f) : QDialog(parent,
     settings.endGroup();
 
     settings.beginGroup("app");
+
+    QString appIcon = settings.value("icon").toString();
+    if (appIcon == "q4wine-ambiance"){
+        comboAppIcons->setCurrentIndex(comboAppIcons->findText(tr("Ambient Light")));
+    } else if (appIcon == "q4wine-ambiance-dark"){
+        comboAppIcons->setCurrentIndex(comboAppIcons->findText(tr("Ambient Dark")));
+    } else {
+        comboAppIcons->setCurrentIndex(comboAppIcons->findText(tr("Default")));
+    }
+
     if (settings.value("showTrareyIcon", 0).toInt()==1){
         cbShowTray->setCheckState(Qt::Checked);
     } else {
@@ -113,52 +123,17 @@ AppSettings::AppSettings(QWidget * parent, Qt::WindowFlags f) : QDialog(parent,
         cbMinimizeToTrayApp->setCheckState(Qt::Unchecked);
     }
 
-        listThemesView->clear();
-
-    std::auto_ptr<QListWidgetItem> iconItem (new QListWidgetItem(listThemesView, 0));
-    iconItem->setText("Default [Aughtor: Xavier Corredor Llano (xavier.corredor.llano@gmail.com); License: GPL v.2.1]");
-    iconItem->setIcon(QIcon(":data/wine.png"));
-    iconItem->setToolTip("Default");
-    listThemesView->setSelectionMode(QAbstractItemView::SingleSelection);
-
-    QString themeDir="";
-
-    themeDir.append(QDir::homePath());
-    themeDir.append("/.config/");
-    themeDir.append(APP_SHORT_NAME);
-    themeDir.append("/theme/");
-
-
-    getThemes(settings.value("theme").toString(), themeDir);
-
     loadThemeIcons();
 
-    if (settings.value("theme").toString()=="Default"){
-        listThemesView->setCurrentItem(iconItem.release());
-    }
-
-    themeDir.clear();
-
-#ifdef _OS_DARWIN_
-    themeDir.append(QDir::currentPath());
-    themeDir.append("/");
-    themeDir.append(APP_SHORT_NAME);
-    themeDir.append(".app/Contents/Resources/theme");
-#else
-    themeDir.append(QString::fromUtf8(APP_PREF));
-    themeDir.append("/share/");
-    themeDir.append(APP_SHORT_NAME);
-    themeDir.append("/theme");
-#endif
-
-    getThemes(settings.value("theme").toString(), themeDir);
-
     getLangs();
 
     if (settings.value("lang").toString().isEmpty()){
         comboLangs->setCurrentIndex(comboLangs->findText(tr("System Default")));
     } else {
-        comboLangs->setCurrentIndex(comboLangs->findText(settings.value("lang").toString()));
+        QString lName = settings.value("lang").toString();
+        //Strip q4wine_ from setting if any
+        lName.replace("q4wine_", "");
+        comboLangs->setCurrentIndex(comboLangs->findText(QLocale(lName).nativeLanguageName()));
     }
 
     settings.endGroup();
@@ -467,71 +442,31 @@ void AppSettings::getLangs(){
 
     for (int i = 0; i < list.size(); ++i) {
         QFileInfo fileInfo = list.at(i);
-        if (fileInfo.fileName().right(2)=="qm")
-            comboLangs->addItem(fileInfo.fileName().split(".").at(0));
+        if (fileInfo.fileName().right(2)=="qm"){
+            QString lName = fileInfo.fileName().replace("q4wine_", "");
+            QLocale lObj = QLocale(lName);
+            QString lNameNative = lObj.nativeLanguageName();
+            lng_hash[lNameNative] = lObj.name();
+            comboLangs->addItem(lNameNative);
+        }
     }
     return;
 }
 
-void AppSettings::getThemes(QString selTheme, QString themeDir){
-    //Getting installed themes
-
-    QString aughtor="", license="";
-
-    QDir tmp(themeDir);
-    tmp.setFilter(QDir::Dirs | QDir::NoSymLinks | QDir::NoDotAndDotDot);
-    QFileInfoList list = tmp.entryInfoList();
-
-    // Getting converted icons from temp directory
-    for (int i = 0; i < list.size(); ++i) {
-        QFileInfo fileInfo = list.at(i);
-        std::auto_ptr<QListWidgetItem> iconItem (new QListWidgetItem(listThemesView, 0));
-
-        QFile file(QString("%1/%2/theme.info").arg(themeDir).arg(fileInfo.fileName()));
-        if (file.open(QIODevice::ReadOnly | QIODevice::Text)){
-            aughtor = file.readLine();
-            aughtor.remove ( "\n" );
-            license = file.readLine();
-        }
-
-        if ((!aughtor.isEmpty()) and (!license.isEmpty())){
-            iconItem->setText(QString("%1 [%2; %3]").arg(fileInfo.fileName()).arg(aughtor).arg(license));
-        } else {
-            iconItem->setText(fileInfo.fileName());
-        }
-        iconItem->setToolTip(QString("%1/%2").arg(themeDir).arg(fileInfo.fileName()));
-        iconItem->setIcon(QIcon(QString("%1/%2/data/wine.png").arg(themeDir).arg(fileInfo.fileName())));
-
-        if (!selTheme.isNull()){
-            if (selTheme==fileInfo.filePath()){
-                //Setting selection to selected theme
-                listThemesView->setCurrentItem(iconItem.release());
-                //Loading pixmaps from theme
-                //loadThemeIcons(fileInfo.filePath());
-            }
-        }
-    }
-
-    return;
-}
-
-
 void AppSettings::loadThemeIcons(){
-    lblLogo->setPixmap(CoreLib->loadPixmap("data/exec.png"));
+    cmdGetTarBin->setIcon(CoreLib->loadIcon("document-open"));
+    cmdGetMountBin->setIcon(CoreLib->loadIcon("document-open"));
+    cmdGetUmountBin->setIcon(CoreLib->loadIcon("document-open"));
+    cmdGetSudoBin->setIcon(CoreLib->loadIcon("document-open"));
+    cmdGetGuiSudoBin->setIcon(CoreLib->loadIcon("document-open"));
+    cmdGetNiceBin->setIcon(CoreLib->loadIcon("document-open"));
+    cmdGetReniceBin->setIcon(CoreLib->loadIcon("document-open"));
+    cmdGetShBin->setIcon(CoreLib->loadIcon("document-open"));
 
-    cmdGetTarBin->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetMountBin->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetUmountBin->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetSudoBin->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetGuiSudoBin->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetNiceBin->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetReniceBin->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetShBin->setIcon(CoreLib->loadIcon("data/folder.png"));
-
-    cmdGetConsoleBin->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetWrestoolBin->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetIcotoolBin->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetDefPrefixPath->setIcon(CoreLib->loadIcon("data/folder.png"));
+    cmdGetConsoleBin->setIcon(CoreLib->loadIcon("document-open"));
+    cmdGetWrestoolBin->setIcon(CoreLib->loadIcon("document-open"));
+    cmdGetIcotoolBin->setIcon(CoreLib->loadIcon("document-open"));
+    cmdGetDefPrefixPath->setIcon(CoreLib->loadIcon("document-open"));
     return;
 }
 
@@ -599,6 +534,15 @@ void AppSettings::cmdOk_Click(){
     settings.endGroup();
 
     settings.beginGroup("app");
+
+    if (comboAppIcons->currentText() == tr("Ambient Light")){
+        settings.setValue("icon", "q4wine-ambiance");
+    } else if (comboAppIcons->currentText() == tr("Ambient Dark")){
+        settings.setValue("icon", "q4wine-ambiance-dark");
+    } else {
+        settings.setValue("icon", "q4wine");
+    }
+
     if (cbShowTray->checkState()==Qt::Checked) {
         settings.setValue("showTrareyIcon", 1);
     } else {
@@ -623,17 +567,10 @@ void AppSettings::cmdOk_Click(){
         settings.setValue("showNotifications", 0);
     }
 
-    if (listThemesView->currentItem()){
-        settings.setValue("theme", listThemesView->currentItem()->toolTip());
-    } else {
-        settings.setValue("theme", "Default");
-    }
-
-
     if (comboLangs->currentText()==tr("System Default")){
         settings.setValue("lang", "");
     } else {
-        settings.setValue("lang", comboLangs->currentText());
+        settings.setValue("lang", lng_hash[comboLangs->currentText()]);
     }
 
     settings.endGroup();
@@ -756,24 +693,18 @@ bool AppSettings::checkEntry(QString fileName, QString info, bool isFile){
       */
 
     if (fileName.isEmpty()){
-        switch (isFile){
-  case false:
+        if (!isFile){
             QMessageBox::warning(this, tr("Error"), tr("Sorry, specify %1 directory.").arg(info));
-            break;
-  case true:
+        } else {
             QMessageBox::warning(this, tr("Error"), tr("Sorry, specify %1 binary.").arg(info));
-            break;
         }
         return false;
     } else {
         if (!QFile::exists(fileName)){
-            switch (isFile){
-   case false:
+            if (!isFile){
                 QMessageBox::warning(this, tr("Error"), tr("Sorry, specified %1 directory does not exist.").arg(info));
-                break;
-   case true:
+            } else {
                 QMessageBox::warning(this, tr("Error"), tr("Sorry, specified %1 binary does not exist.").arg(info));
-                break;
             }
             return false;
         }
