@@ -56,10 +56,9 @@ FakeDriveSettings::FakeDriveSettings(QString prefixName, QWidget * parent, Qt::W
     widgetContent->setLayout(vlayout.release());
 
     setWindowTitle(tr("Fake drive settings"));
-    lblCaption->setText(tr("Fake drive settings for prefix \"%1\"").arg(this->prefixName));
+    setWindowIcon(CoreLib->loadIcon(CoreLib->getSetting("app", "icon", false, "q4wine").toString()));
 
     connect(optionsTree, SIGNAL(itemClicked (QTreeWidgetItem *, int)), this, SLOT(optionsTree_itemClicked ( QTreeWidgetItem *, int)));
-
     connect(cmdCancel, SIGNAL(clicked()), this, SLOT(cmdCancel_Click()));
     QString pic="", line="", prefixPath="";
     connect(cmdOk, SIGNAL(clicked()), this, SLOT(cmdOk_Click()));
@@ -105,10 +104,10 @@ void FakeDriveSettings::optionsTree_itemClicked ( QTreeWidgetItem *item, int){
     } else if (itemText==tr("Video")){
         optionsStack->setCurrentIndex(1);
         tabwVideo->setCurrentIndex(0);
-    } else if (itemText==tr("Direct3D") && item->parent()->text(0)==tr("Video")){
+    } else if (itemText=="Direct3D" && item->parent()->text(0)==tr("Video")){
         optionsStack->setCurrentIndex(1);
         tabwVideo->setCurrentIndex(1);
-    } else if (itemText==tr("OpenGL")){
+    } else if (itemText=="OpenGL"){
         optionsStack->setCurrentIndex(1);
         tabwVideo->setCurrentIndex(2);
     } else if (itemText==tr("X11 Driver") && item->parent()->text(0)==tr("Video")){
@@ -138,7 +137,7 @@ void FakeDriveSettings::optionsTree_itemClicked ( QTreeWidgetItem *item, int){
     } else if (itemText==tr("Input")){
         optionsStack->setCurrentIndex(4);
         tabwInput->setCurrentIndex(0);
-    } else if (itemText==tr("Direct3D") && item->parent()->text(0)==tr("Input")){
+    } else if (itemText=="Direct3D" && item->parent()->text(0)==tr("Input")){
         optionsStack->setCurrentIndex(4);
         tabwInput->setCurrentIndex(0);
     } else if (itemText==tr("X11 Driver") && item->parent()->text(0)==tr("Input")){
@@ -821,9 +820,9 @@ void FakeDriveSettings::cmdHelp_Click(){
         rawurl = "07-fake-drive-settings.html#winebrowsers";
     } else if (itemText==tr("Video")){
         rawurl = "07-fake-drive-settings.html#video";
-    } else if (itemText==tr("Direct3D") && item->parent()->text(0)==tr("Video")){
+    } else if (itemText=="Direct3D" && item->parent()->text(0)==tr("Video")){
         rawurl = "07-fake-drive-settings.html#direct";
-    } else if (itemText==tr("OpenGL")){
+    } else if (itemText=="OpenGL"){
         rawurl = "07-fake-drive-settings.html#opengl";
     } else if (itemText==tr("X11 Driver") && item->parent()->text(0)==tr("Video")){
         rawurl = "07-fake-drive-settings.html#x11-video";
@@ -856,19 +855,17 @@ void FakeDriveSettings::cmdHelp_Click(){
 }
 
 void FakeDriveSettings::loadThemeIcons(){
-    lblLogo->setPixmap(CoreLib->loadPixmap("data/exec.png"));
     connect(cmdJoystickEdit, SIGNAL(clicked()), this, SLOT(cmdJoystickEdit_Click()));
     connect(cmdJoystickAdd, SIGNAL(clicked()), this, SLOT(cmdJoystickAdd_Click()));
     connect(cmdJoystickDel, SIGNAL(clicked()), this, SLOT(cmdJoystickDel_Click()));
     connect(cmdWineDriveEdit, SIGNAL(clicked()), this, SLOT(cmdWineDriveEdit_Click()));
     connect(cmdWineDriveAdd, SIGNAL(clicked()), this, SLOT(cmdWineDriveAdd_Click()));
     connect(cmdWineDriveDel, SIGNAL(clicked()), this, SLOT(cmdWineDriveDel_Click()));
-    cmdGetWineDesktop->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetWineDesktopDoc->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetWineDesktopPic->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetWineDesktopMus->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetWineDesktopVid->setIcon(CoreLib->loadIcon("data/folder.png"));
-
+    cmdGetWineDesktop->setIcon(CoreLib->loadIcon("document-open"));
+    cmdGetWineDesktopDoc->setIcon(CoreLib->loadIcon("document-open"));
+    cmdGetWineDesktopPic->setIcon(CoreLib->loadIcon("document-open"));
+    cmdGetWineDesktopMus->setIcon(CoreLib->loadIcon("document-open"));
+    cmdGetWineDesktopVid->setIcon(CoreLib->loadIcon("document-open"));
     return;
 }
 
