@@ -52,10 +52,10 @@ IconSettings::IconSettings(QString prefix_name, QString dir_name, QString icon_n
     this->icon_name = icon_name;
     this->prefix_path = result.value("path");
     if (this->prefix_path.isEmpty()){
-          this->prefix_path = QDir::homePath();
-          this->prefix_path.append("/.wine/drive_c/");
+        this->prefix_path = QDir::homePath();
+        this->prefix_path.append("/.wine/drive_c/");
     } else {
-          this->prefix_path.append("/drive_c/");
+        this->prefix_path.append("/drive_c/");
     }
 
 
@@ -72,27 +72,22 @@ IconSettings::IconSettings(QString prefix_name, QString dir_name, QString icon_n
       if (QDir().exists(cd_mount))
           prefix_urls << QUrl::fromLocalFile(cd_mount);
 
+    setWindowIcon(CoreLib->loadIcon(CoreLib->getSetting("app", "icon", false, "q4wine").toString()));
     this->loadThemeIcons();
 
 
     QString res;
-    switch (icon_name.isEmpty()){
-        case true:
-            lblCaption->setText(tr("Adding new icon"));
+    if (icon_name.isEmpty()){
             setWindowTitle(tr("Adding new icon"));
-
             res = CoreLib->getSetting("advanced", "defaultDesktopSize", false, "").toString();
             if (res.isEmpty()){
                 cboxDesktopSize->setCurrentIndex(0);
             } else {
                 cboxDesktopSize->setCurrentIndex(cboxDesktopSize->findText(res));
             }
-        break;
-        case false:
-            lblCaption->setText(tr("Icon settings"));
+    } else {
             setWindowTitle(tr("Icon settings"));
             getIconReccord();
-        break;
     }
 
     connect(cmdAdd, SIGNAL(clicked()), this, SLOT(cmdAdd_Click()));
@@ -141,12 +136,11 @@ IconSettings::IconSettings(QString prefix_name, QString dir_name, QString icon_n
 }
 
 void IconSettings::loadThemeIcons(){
-    lblLogo->setPixmap(CoreLib->loadPixmap("data/exec.png"));
-    cmdGetProgram->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetWorkDir->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetIcon->setIcon(CoreLib->loadIcon("data/exec_wine.png"));
-    cmdGetPreRun->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetPostRun->setIcon(CoreLib->loadIcon("data/folder.png"));
+    cmdGetProgram->setIcon(CoreLib->loadIcon("document-open"));
+    cmdGetWorkDir->setIcon(CoreLib->loadIcon("document-open"));
+    cmdGetIcon->setIcon(CoreLib->loadIcon("application-x-ms-dos-executable"));
+    cmdGetPreRun->setIcon(CoreLib->loadIcon("document-open"));
+    cmdGetPostRun->setIcon(CoreLib->loadIcon("document-open"));
     return;
 }
 
@@ -165,12 +159,12 @@ void IconSettings::getIconReccord(){
         if (QFile(iconPath).exists()){
             cmdGetIcon->setIcon (QIcon(iconPath));
         } else {
-            QIcon ico = CoreLib->loadIcon(QString("data/%1.png").arg(iconPath));
+            QIcon ico = CoreLib->loadIcon(iconPath);
 
             // Do not work due to: https://bugreports.qt-project.org/browse/QTBUG-999
             //if (ico.isNull()){
             if (ico.availableSizes().isEmpty()){
-                ico = CoreLib->loadIcon("data/exec_wine.png");
+                ico = CoreLib->loadIcon("application-x-ms-dos-executable");
                 iconPath="";
             }
 
@@ -400,7 +394,7 @@ void IconSettings::getProgramIcon(QString name){
         cmdGetIcon->setIcon (QIcon(list.at(0).filePath()));
         this->iconPath=list.at(0).filePath();
     } else {
-        cmdGetIcon->setIcon(CoreLib->loadIcon("data/exec_wine.png"));
+        cmdGetIcon->setIcon(CoreLib->loadIcon("application-x-ms-dos-executable"));
     }
     return;
 }
@@ -436,9 +430,9 @@ void IconSettings::cmdGetIcon_Click(){
       dialog.setDirectory(searchPath);
 
         #ifndef WITH_ICOUTILS
-        dialog.setNameFilter(tr("Image files (*.png *.jpg *.gif *.bmp *.xpm)"));
+        dialog.setNameFilter(tr("Image files (*.png *.jpg *.gif *.bmp *.xpm *.svg *.svgz)"));
         #else
-        dialog.setNameFilter(tr("Image and Win32 binary files (*.png *.jpg *.gif *.bmp *.xpm *.exe *.dll);;Image files (*.png *.jpg *.gif *.bmp *.xpm);;Win32 Executable (*.exe);;Win32 Shared libraries (*.dll);;Win32 Executable and Shared libraries (*.exe *.dll)"));
+        dialog.setNameFilter(tr("Image and Win32 binary files (*.png *.jpg *.gif *.bmp *.xpm *.exe *.dll);;Image files (*.png *.jpg *.gif *.bmp *.xpm *.svg *.svgz);;Win32 Executable (*.exe);;Win32 Shared libraries (*.dll);;Win32 Executable and Shared libraries (*.exe *.dll)"));
         #endif
       //dialog.setSidebarUrls(add_prefix_urls);
 
@@ -513,7 +507,7 @@ void IconSettings::cmdGetIcon_Click(){
                         IconsView iconsView(tmpDir);
                         if (iconsView.exec()==QDialog::Accepted){
                             fileName=iconsView.selectedFile;
-                            cmdGetIcon->setIcon (QIcon(fileName));
+                            cmdGetIcon->setIcon(QIcon(fileName));
                         } else {
                             fileName.clear();
                         }
@@ -522,7 +516,7 @@ void IconSettings::cmdGetIcon_Click(){
                     IconsView iconsView(tmpDir);
                     if (iconsView.exec()==QDialog::Accepted){
                         fileName=iconsView.selectedFile;
-                        cmdGetIcon->setIcon (QIcon(fileName));
+                        cmdGetIcon->setIcon(QIcon(fileName));
                     } else {
                         fileName.clear();
                     }
@@ -619,15 +613,13 @@ void IconSettings::cmdOk_Click(){
     if (desktopSize==tr("No virtual desktop"))
         desktopSize="";
 
-    switch (this->icon_name.isEmpty()){
-        case true:
+    if (this->icon_name.isEmpty()){
             db_icon.addIcon(txtCmdArgs->text(), txtProgramPath->text(), iconPath, txtDesc->text(), this->prefix_name, this->dir_name, txtName->text(), override, txtWinedebug->text(), useconsole, txtDisplay->text(), txtWorkDir->text(), desktopSize, spinNice->value(), txtEnvLang->text(), txtPreRun->text(), txtPostRun->text());
 #ifndef _OS_DARWIN_
             if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool())
                 CoreLib->createDesktopFile(this->prefix_name, this->dir_name, txtName->text(), true);
 #endif
-        break;
-        case false:
+    } else {
             db_icon.updateIcon(txtCmdArgs->text(), txtProgramPath->text(), iconPath, txtDesc->text(), this->prefix_name, this->dir_name, txtName->text(), icon_name, override, txtWinedebug->text(), useconsole, txtDisplay->text(), txtWorkDir->text(), desktopSize, spinNice->value(), txtEnvLang->text(), txtPreRun->text(), txtPostRun->text());
 #ifndef _OS_DARWIN_
             if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool()){
@@ -635,7 +627,6 @@ void IconSettings::cmdOk_Click(){
                 CoreLib->createDesktopFile(this->prefix_name, this->dir_name, txtName->text(), true);
             }
 #endif
-        break;
     }
 
     accept();
