@@ -43,6 +43,8 @@ PrefixSettings::PrefixSettings(QString prefix_name, QWidget * parent, Qt::Window
     this->addNew=false;
     this->loadThemeIcons();
 
+    setWindowIcon(CoreLib->loadIcon(CoreLib->getSetting("app", "icon", false, "q4wine").toString()));
+
     QHash<QString,QString> result = db_prefix.getByName(prefix_name);
     if (result.value("id").isEmpty())
         return;
@@ -140,7 +142,6 @@ PrefixSettings::PrefixSettings(QWidget * parent, Qt::WindowFlags f) : QDialog(pa
     setupUi(this);
 
     this->setWindowTitle(tr("Add new Prefix"));
-    this->lblCaption->setText(tr("Add new Prefix"));
     this->addNew=true;
 
     // Loading libq4wine-core.so
@@ -158,6 +159,7 @@ PrefixSettings::PrefixSettings(QWidget * parent, Qt::WindowFlags f) : QDialog(pa
     CoreLibClassPointer = (CoreLibPrototype *) libq4wine.resolve("createCoreLib");
     CoreLib.reset((corelib *)CoreLibClassPointer(true));
 
+    setWindowIcon(CoreLib->loadIcon("q4wine"));
     this->loadThemeIcons();
 
     cmdGetPrefixPath->installEventFilter(this);
@@ -198,16 +200,13 @@ QString PrefixSettings::getPrefixName(){
 }
 
 void PrefixSettings::loadThemeIcons(){
-    lblLogo->setPixmap(CoreLib->loadPixmap("data/exec.png"));
-
-    cmdClnWineBin->setIcon(CoreLib->loadIcon("data/kill.png"));
-    cmdClnWineServerBin->setIcon(CoreLib->loadIcon("data/kill.png"));
-    cmdClnWineLoaderBin->setIcon(CoreLib->loadIcon("data/kill.png"));
-    cmdClnWineLibs->setIcon(CoreLib->loadIcon("data/kill.png"));
-    cmdGetMountPoint->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetPrefixPath->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdAddVersion->setIcon(CoreLib->loadIcon("data/add.png"));
-
+    cmdClnWineBin->setIcon(CoreLib->loadIcon("edit-delete"));
+    cmdClnWineServerBin->setIcon(CoreLib->loadIcon("edit-delete"));
+    cmdClnWineLoaderBin->setIcon(CoreLib->loadIcon("edit-delete"));
+    cmdClnWineLibs->setIcon(CoreLib->loadIcon("edit-delete"));
+    cmdGetMountPoint->setIcon(CoreLib->loadIcon("document-open"));
+    cmdGetPrefixPath->setIcon(CoreLib->loadIcon("document-open"));
+    cmdAddVersion->setIcon(CoreLib->loadIcon("document-new"));
     return;
 }
 
