@@ -36,6 +36,8 @@ WineDriveDialog::WineDriveDialog(QStringList removeLetters, QWidget * parent, Qt
 	CoreLibClassPointer = (CoreLibPrototype *) libq4wine.resolve("createCoreLib");
 	CoreLib.reset((corelib *)CoreLibClassPointer(true));
 
+    setWindowIcon(CoreLib->loadIcon(CoreLib->getSetting("app", "icon", false, "q4wine").toString()));
+
 	if (removeLetters.count()>0){
 		for (int i=0; i<removeLetters.count(); i++){
 			if (cbDriveLetter->findText(removeLetters.at(i), Qt::MatchExactly)>=0){
@@ -52,7 +54,7 @@ WineDriveDialog::WineDriveDialog(QStringList removeLetters, QWidget * parent, Qt
 	connect(cmdOk, SIGNAL(clicked()), this, SLOT(cmdOk_Click()));
 	connect(cmdGetDrivePath, SIGNAL(clicked()), this, SLOT(cmdGetDrivePath_Click()));
 
-	cmdGetDrivePath->setIcon(CoreLib->loadIcon("data/folder.png"));
+    cmdGetDrivePath->setIcon(CoreLib->loadIcon("document-open"));
 
 	cmdOk->setFocus(Qt::ActiveWindowFocusReason);
 
@@ -103,7 +105,7 @@ WineDriveDialog::WineDriveDialog(QStringList removeLetters, QString driveLetter,
 	connect(cmdOk, SIGNAL(clicked()), this, SLOT(cmdOk_Click()));
 	connect(cmdGetDrivePath, SIGNAL(clicked()), this, SLOT(cmdGetDrivePath_Click()));
 
-	cmdGetDrivePath->setIcon(CoreLib->loadIcon("data/folder.png"));
+    cmdGetDrivePath->setIcon(CoreLib->loadIcon("document-open"));
 
 	cmdOk->setFocus(Qt::ActiveWindowFocusReason);
 }
