@@ -35,7 +35,6 @@ QList<QStringList> corelib::getWineProcessList(const QString prefix_name){
     QList<QStringList> proclist;
     QStringList procline;
 
-
     QString prefix_path;
 
     if (!prefix_name.isEmpty())
@@ -78,67 +77,70 @@ QList<QStringList> corelib::getWineProcessList(const QString prefix_name){
         QFileInfo fileInfo = list.at(i);
         path = "/proc/";
         path.append(fileInfo.fileName());
-        path.append("/stat");
-        QFile file(path);
-        path = "/proc/";
-        path.append(fileInfo.fileName());
-        path.append("/exe");
-        QFileInfo exelink(path);
-        // Try to read stat file
-        if (exelink.isSymLink() && (exelink.symLinkTarget().contains("wineserver") || exelink.symLinkTarget().contains("wine-preloader") || exelink.symLinkTarget().contains("wine64-preloader"))){
-            if (file.open(QIODevice::ReadOnly | QIODevice::Text)){
-                QTextStream in(&file);
-                QString line = in.readLine();
-                if (!line.isNull()){
-                    // Getting nice and name of the process
-                    nice = line.section(' ', 18, 18);
-                    name = line.section(' ', 1, 1);
-                    name.remove(QChar('('));
-                    name.remove(QChar(')'));
-                    name = name.toLower();
+        path.append("/comm");
+        QFile file_c(path);
+        if (file_c.open(QIODevice::ReadOnly | QIODevice::Text)){
+            // Try to read com file
+            QTextStream in(&file_c);
+            QString name = in.readLine();
+#ifdef DEBUG
+            qDebug()<<"path: "<<fileInfo.fileName()<<" comm: "<<name;
+#endif
+            if ((name.contains("wine") || name.contains(".exe")) && !name.contains(APP_SHORT_NAME)){
+                path = "/proc/";
+                path.append(fileInfo.fileName());
+                path.append("/stat");
+                QFile file_s(path);
+                if (file_s.open(QIODevice::ReadOnly | QIODevice::Text)){
+                    // Try to read com file
+                    QTextStream in(&file_s);
+                    QString line = in.readLine();
+                    if (!line.isNull()){
+                        // Getting nice and name of the process
+                        nice = line.section(' ', 18, 18);
+                        name = line.section(' ', 1, 1);
+                        name.remove(QChar('('));
+                        name.remove(QChar(')'));
+                        name = name.toLower();
 
-                    // If name contains wine or .exe and not contains q4wine,
-                    // then we try to get environ variables.
-                    //if ((name.contains("wine") || name.contains(".exe")) && !name.contains(APP_SHORT_NAME)){
-                    path = "/proc/";
-                    path.append(fileInfo.fileName());
-                    path.append("/environ");
-                    QFile e_file(path);
-
-                    // Getting WINEPREFIX variable.
-                    if (e_file.open(QIODevice::ReadOnly | QIODevice::Text)){
-                        QTextStream e_in(&e_file);
-                        QString e_line = e_in.readLine();
-                        int index = e_line.indexOf("WINEPREFIX=");
-                        prefix="";
-                        if (index!=-1)
-                            for (int i=index+11; i<=e_line.length(); i++){
-                            if (e_line.mid(i, 1).data()->isPrint()){
-                                prefix.append(e_line.mid(i, 1));
-                            } else {
-                                break;
-                            }
+                        path = "/proc/";
+                        path.append(fileInfo.fileName());
+                        path.append("/environ");
+                        QFile file_e(path);
+                        // Getting WINEPREFIX variable.
+                        if (file_e.open(QIODevice::ReadOnly | QIODevice::Text)){
+                            // Try to read environ file
+                            QTextStream e_in(&file_e);
+                            QString e_line = e_in.readLine();
+                            int index = e_line.indexOf("WINEPREFIX=");
+                            prefix="";
+                            if (index!=-1)
+                                for (int i=index+11; i<=e_line.length(); i++){
+                                    if (e_line.mid(i, 1).data()->isPrint()){
+                                        prefix.append(e_line.mid(i, 1));
+                                    } else {
+                                        break;
+                                    }
+                                }
+                            file_e.close();
                         }
-                    }
 
-                    // Puting all fields into QList<QStringList>
-                    procline.clear();
-
-
-                    if (!prefix_path.isNull()){
-                        if (prefix_path == prefix){
+                        // Puting all fields into QList<QStringList>
+                        procline.clear();
+                        if (!prefix_path.isNull()){
+                            if (prefix_path == prefix){
+                                procline << fileInfo.fileName() << name << nice << prefix;
+                                proclist << procline;
+                            }
+                        } else {
                             procline << fileInfo.fileName() << name << nice << prefix;
                             proclist << procline;
                         }
-                    } else {
-                        procline << fileInfo.fileName() << name << nice << prefix;
-                        proclist << procline;
                     }
-
-                    //}
+                    file_s.close();
                 }
-                file.close();
             }
+            file_c.close();
         }
     }
 #endif
@@ -308,24 +310,6 @@ void corelib::checkSettings(){
     /*
      * Getting application settings
      */
-    QString lib32 = this->getSetting("wine", "WineLibs32", false, "").toString();
-    QString lib64 = this->getSetting("wine", "WineLibs64", false, "").toString();
-    if (lib32.isEmpty() and lib64.isEmpty()){
-        QStringList libs_path = this->getWineLibsPath();
-        QSettings settings(APP_SHORT_NAME, "default");
-        settings.beginGroup("wine");
-        settings.setValue("WineLibs32", libs_path.at(0));
-        settings.setValue("WineLibs64", libs_path.at(1));
-        settings.endGroup();
-    }
-
-    lib32 = this->getSetting("wine", "WineLibs32", false, "").toString();
-    lib64 = this->getSetting("wine", "WineLibs64", false, "").toString();
-    if (lib32.isEmpty() and lib64.isEmpty()){
-        this->showError(QObject::tr("<p>Error while loading application settings. wine's library path for 32 and 64 bit is not set.</p><p>Please, go to the %1 options dialog and set at least one path.</p>").arg(APP_SHORT_NAME));
-
-    }
-
     this->getSetting("system", "tar");
     this->getSetting("system", "mount");
     this->getSetting("system", "umount");
@@ -373,23 +357,10 @@ void corelib::checkSettings(){
     return;
 }
 
-QIcon corelib::loadIcon(QString iconName){
+QIcon corelib::loadIcon(QString iconName, bool fromTheme){
     // Function tryes to load icon image from theme dir
     // If it fails -> load default from rsource file
-
-    QIcon icon;
-    QString themeName = this->getSetting("app", "theme", false, "Default").toString();
-
-    if ((!themeName.isEmpty()) and (themeName!="Default")){
-        icon.addFile(QString("%1/%2").arg(themeName).arg(iconName));
-        if (icon.isNull()){
-            icon.addFile(QString(":/%1").arg(iconName));
-        }
-    } else {
-        icon.addFile(QString(":/%1").arg(iconName));
-    }
-
-    return icon;
+    return QIcon::fromTheme(iconName, QIcon(QString(":%1").arg(iconName)));
 }
 
 QPixmap corelib::loadPixmap(QString iconName){
@@ -397,17 +368,7 @@ QPixmap corelib::loadPixmap(QString iconName){
     // If it fails -> load default from rsource file
 
     QPixmap pixmap;
-    QString themeName = this->getSetting("app", "theme", false, "Default").toString();
-
-    if ((!themeName.isEmpty()) and (themeName!="Default")){
-        pixmap.load(QString("%1/%2").arg(themeName).arg(iconName));
-        if (pixmap.isNull()){
-            pixmap.load(QString(":/%1").arg(iconName));
-        }
-    } else {
-        pixmap.load(QString(":/%1").arg(iconName));
-    }
-
+    pixmap.load(QString(":/%1").arg(iconName));
     return pixmap;
 }
 
@@ -434,65 +395,47 @@ QString corelib::getTranslationLang(){
 
     if (!lang.isNull()){
         if (qtt.load(lang, i18nPath)){
-            qDebug()<<"[ii] loaded:"<<lang;
+            qDebug()<<"[ii] Loading translation: "<<lang;
             return lang;
         } else {
-            qDebug()<<"[EE] Cannot open user selected translation";
-            if (qtt.load("q4wine_en_us", i18nPath)){
-                return "q4wine_en_us";
+            qDebug()<<"[EE] Cannot open user selected translation: "<<lang;
+            lang = this->getLang(false);
+            if (qtt.load(lang, i18nPath)){
+                qDebug()<<"[ii] Loading translation: "<<lang;
+                return lang;
             } else {
-                qDebug()<<"[EE] Cannot open default translation, fall back to native translation ;[";
+                qDebug()<<"[EE] Cannot open system selected translation: "<<lang;
+                if (qtt.load("q4wine_en", i18nPath)){
+                    qDebug()<<"[ii] Loading translation: q4wine_en"<<lang;
+                    return "q4wine_en";
+                } else {
+                    qDebug()<<"[EE] Cannot open default translation, not using translation engine.";
+                }
             }
         }
     } else {
-        qDebug()<<"[EE] Cannot get LANG variable, fall back to native translation ;[";
+        qDebug()<<"[EE] Cannot get system locale, not using translation engine.";
     }
     return "";
 }
 
-QString  corelib::getLang(){
-    QString lang=this->getSetting("app", "lang", false).toString();
+QString  corelib::getLang(bool fromSettings){
+    QString lang;
 
-    if (!lang.isEmpty()){
-        if (!lang.contains("q4wine")){
-            lang = QString("q4wine_%1").arg(lang);
-        }
+    if (fromSettings){
+        lang=this->getSetting("app", "lang", false).toString();
+        if (!lang.isEmpty()){
+            if (!lang.contains("q4wine")){
+                lang = QString("q4wine_%1").arg(lang);
+            }
 #ifdef DEBUG
-        qDebug()<<"[ii] Get lang from settings:"<<lang;
-#endif
-        return lang;
-    }
-
-    // This is hack for next QLocale bug:
-    //  http://bugs.gentoo.org/150745
-
-    lang = setlocale(LC_ALL, "");
-#ifdef DEBUG
-    qDebug()<<"[ii] LC_ALL: "<<lang;
-#endif
-    if (lang.isEmpty()){
-        lang = setlocale(LC_MESSAGES, "");
-#ifdef DEBUG
-        qDebug()<<"[ii] LC_MESSAGES: "<<lang;
-#endif
-        if (lang.isEmpty()){
-            lang = getenv("LANG");
-#ifdef DEBUG
-            qDebug()<<"[ii] Env LANG: "<<lang;
+            qDebug()<<"[ii] Get lang from settings:"<<lang;
 #endif
+            return lang;
         }
     }
 
-#ifdef DEBUG
-    qDebug()<<"[ii] Lang before split: "<<lang;
-#endif
-
-    lang = lang.split(".").at(0).toLower();
-    if (lang.contains("=")){
-        lang = lang.split("=").last();
-    }
-
-    lang = QString("q4wine_%1").arg(lang);
+    lang = QString("q4wine_%1").arg(QLocale::system().name());
 
 #ifdef DEBUG
     qDebug()<<"[ii] Lang to load: "<<lang;
@@ -501,45 +444,11 @@ QString  corelib::getLang(){
 }
 
 QString  corelib::getLocale(){
-    QString lang;
-        lang = setlocale(LC_ALL, "");
+    QString lang = QLocale::system().name();
 #ifdef DEBUG
-        qDebug()<<"[ii] LC_ALL: "<<lang;
+    qDebug()<<"[ii] Locale to use: "<<lang;
 #endif
-        if (lang.isEmpty()){
-                lang = setlocale(LC_MESSAGES, "");
-#ifdef DEBUG
-                qDebug()<<"[ii] LC_MESSAGES: "<<lang;
-#endif
-                if (lang.isEmpty()){
-                        lang = getenv("LANG");
-#ifdef DEBUG
-                        qDebug()<<"[ii] Env LANG: "<<lang;
-#endif
-                }
-        }
-
-#ifdef DEBUG
-        qDebug()<<"[ii] Lang before split: "<<lang;
-#endif
-
-        QStringList loc = lang.split(".");
-#ifdef DEBUG
-        qDebug()<<"[ii] loc.count(): "<<loc.count();
-#endif
-        if (loc.count()==2){
-            lang = loc.at(1).toLower();
-        } else {
-            lang = "utf8";
-        }
-
-        if (lang.contains(";"))
-            lang = lang.split(";").first();
-
-#ifdef DEBUG
-        qDebug()<<"[ii] Locale to use: "<<lang;
-#endif
-        return lang;
+    return lang;
 }
 
 bool corelib::isConfigured(){
@@ -678,111 +587,6 @@ QString corelib::getWhichOut(const QString fileName, bool showErr){
     return "";
 }
 
-QStringList corelib::getWineLibsPath(void) {
-    QProcess proc;
-    QStringList args;
-    QStringList libs_path;
-    libs_path << "" << ""; // 32, 64
-
-#ifndef _OS_MACOSX_
-    QString sh = this->getWhichOut("sh");
-    if (sh.isEmpty())
-        return libs_path;
-
-    QString ldconfig = this->getWhichOut("ldconfig", false);
-    if (ldconfig.isEmpty())
-        ldconfig = "/sbin/ldconfig";
-
-#ifdef _OS_LINUX_
-    ldconfig.append(" -p ");
-#else
-    ldconfig.append(" -r ");
-#endif
-    ldconfig.append(" | grep libwine.so");
-
-    args<<"-c"<<ldconfig;
-
-    proc.setWorkingDirectory (QDir::homePath());
-    proc.start(sh, args, QIODevice::ReadOnly);
-    proc.waitForFinished();
-
-    if (proc.exitCode() != 0){
-        qDebug()<<"[EE] Cannot get ldconfig data";
-        return libs_path;
-    }
-
-    QString string = proc.readAllStandardOutput();
-#ifdef DEBUG
-    qDebug()<<"[ii]"<<string;
-#endif
-    if (!string.isEmpty()){
-        QStringList libs_list = string.split("\n");
-#ifdef _OS_LINUX_
-        QRegExp rx_info(".*\\((.*)\\) => (.*\\.so.*$)");
-#else
-        QRegExp rx_info("(.*) => (.*\\.so.*)");
-#endif
-        foreach (QString lib_info, libs_list){
-#ifdef DEBUG
-            qDebug()<<"[ii] work with: " <<  lib_info;
-#endif
-            int pos = rx_info.indexIn(lib_info);
-            QString arch, path;
-            if (pos > -1) {
-                arch = rx_info.cap(1).split(",").last();
-                path = rx_info.cap(2);
-            } else {
-                continue;
-            }
-#ifdef DEBUG
-            qDebug()<<"[ii] Found: " <<  arch << " " << path;
-#endif
-            if (path.isEmpty()){
-                qDebug()<<"[EE] No winelib.so found in: " << lib_info;
-                continue;
-            }
-            QFileInfo file(path);
-
-            if (!file.exists()){
-                qDebug()<<"[EE] File does not exist: " << path;
-                continue;
-            }
-            path = file.absolutePath().append("/wine/");
-            file.setFile(path);
-            if (!file.isDir()){
-                qDebug()<<"[EE] Directory does not exist:"<<path;
-                continue;
-            } else {
-                if (arch == "x86-64"){
-                    libs_path.replace(1, path);
-                } else {
-                    libs_path.replace(0, path);
-                }
-            }
-        }
-    }
-#else
-    //FIXME: Design search for brew packages: /usr/local/Cellar/wine/1.2.3/lib
-    QStringList libs_loc, libs_arch;
-    libs_loc << "/usr/lib" << "/usr/local/lib" << "/local/usr/lib" << "/opt/local/lib";
-    libs_arch << "64" << "32" << "";
-    foreach (QString loc, libs_loc){
-        foreach (QString arch, libs_arch){
-            loc.append(arch);
-            QString libwine_path = loc;
-            libwine_path.append("/libwine.dylib");
-            if (QFile(libwine_path).exists()){
-                loc.append("/wine");
-                libs_path.replace(0, loc);
-                libs_path.replace(1, loc);
-                break;
-            }
-        }
-    }
-#endif
-    return libs_path;
-}
-
 QStringList corelib::getCdromDevices(void) const{
     QStringList retVal;
 #ifdef _OS_DARWIN_
@@ -852,7 +656,7 @@ QStringList corelib::getCdromDevices(void) const{
     QStringList corelib::getWineDlls(QString prefix_lib_path) const{
         QStringList dllList;
         if (prefix_lib_path.isEmpty()){
-            prefix_lib_path=this->getSetting("wine", "WineLibs").toString();
+            prefix_lib_path=this->getSetting("wine", "WineLibs", false, "").toString();
         }
 
         QDir dir(prefix_lib_path);
@@ -1228,6 +1032,11 @@ QStringList corelib::getCdromDevices(void) const{
             //FIXME:
             QString base_icon = QString("%1/.local/share/applications/").arg(QDir::homePath());
 
+#ifdef _OS_DARWIN_
+            QString embedded_icon_path = QString("%1/%2.app/Contents/Resources/icons/share/q4wine/icons/").arg(APP_PREF, APP_NAME);
+#else
+            QString embedded_icon_path = QString("%1/share/q4wine/icons/").arg(APP_PREF);
+#endif
 
             if (is_menu){
                 fileName = base_icon;
@@ -1261,18 +1070,46 @@ QStringList corelib::getCdromDevices(void) const{
             QString icon_path = result.value("icon_path");
 
             if (icon_path.isEmpty()){
-                out<<"Icon="<<QString::fromUtf8(APP_PREF)<<"/share/q4wine/icons/exec_wine.png"<<endl;
+                out<<"Icon=application-x-ms-dos-executable"<<endl;
             } else {
                 if (QFile(icon_path).exists()){
                     out<<"Icon="<<icon_path<<endl;
                 } else {
-                    out<<"Icon="<<QString::fromUtf8(APP_PREF)<<"/share/q4wine/icons/"<<icon_name<<".png"<<endl;
+                    if (icon_name == "eject"){
+                        out<<"Icon="<<embedded_icon_path<<"cdrom"<<".svg"<<endl;
+                    } else if (icon_name == "explorer"){
+                        out<<"Icon="<<embedded_icon_path<<"winefile"<<".svg"<<endl;
+                    } else if (icon_name == "winecfg"){
+                        out<<"Icon="<<embedded_icon_path<<icon_name<<".svg"<<endl;
+                    } else if (icon_name == "iexplore"){
+                        out<<"Icon="<<embedded_icon_path<<icon_name<<".svg"<<endl;
+                    } else if (icon_name == "oleview"){
+                        out<<"Icon="<<embedded_icon_path<<"oic_winlogo"<<".svg"<<endl;
+                    } else if (icon_name == "taskmgr"){
+                        out<<"Icon="<<embedded_icon_path<<icon_name<<".svg"<<endl;
+                    } else if (icon_name == "control"){
+                        out<<"Icon="<<embedded_icon_path<<icon_name<<".svg"<<endl;
+                    } else if (icon_name == "notepad"){
+                        out<<"Icon="<<embedded_icon_path<<icon_name<<".svg"<<endl;
+                    } else if (icon_name == "regedit"){
+                        out<<"Icon="<<embedded_icon_path<<icon_name<<".svg"<<endl;
+                    } else if (icon_name == "uninstaller"){
+                        out<<"Icon="<<embedded_icon_path<<"trash_file"<<".svg"<<endl;
+                    } else if (icon_name == "winemine"){
+                        out<<"Icon="<<embedded_icon_path<<icon_name<<".svg"<<endl;
+                    } else if (icon_name == "wordpad"){
+                        out<<"Icon="<<embedded_icon_path<<icon_name<<".svg"<<endl;
+                    } else if (icon_name == "wineconsole"){
+                        out<<"Icon="<<embedded_icon_path<<"wcmd"<<".svg"<<endl;
+                    } else {
+                        out<<"Icon=application-x-ms-dos-executable"<<endl;
+                    }
                 }
             }
             out<<"Type=Application"<<endl;
             out<<"StartupNotify=true"<<endl;
-            out<<"GenericName="<<result.value("name")<<endl;
-            out<<"Name="<<result.value("name")<<endl;
+            out<<"GenericName="<<icon_name<<endl;
+            out<<"Name="<<icon_name<<endl;
             out<<"Path="<<result.value("wrkdir")<<endl;
 
             file.close();
@@ -1581,35 +1418,26 @@ QStringList corelib::getCdromDevices(void) const{
         }
 
         int corelib::showError(const QString message, const bool info) const{
-            switch (this->_GUI_MODE){
-   case true:
-                switch (info){
-    case true:
+            if (this->_GUI_MODE){
+                if (info){
                     QMessageBox::warning(0, QObject::tr("Error"), message);
                     return 0;
-                    break;
-    case false:
+                } else {
                     return QMessageBox::warning(0, QObject::tr("Error"), message, QMessageBox::Retry, QMessageBox::Ignore);
-                    break;
                 }
-                break;
-            case false:
+            } else {
                 QTextStream stdErr(stderr);
                 stdErr<<"[ee] "<<message<<endl; // message.toLatin1();
-                break;
             }
             return 0;
         }
 
         void corelib::showError(const QString message) const{
             QTextStream Qcout(stdout);
-            switch (this->_GUI_MODE){
-   case true:
+            if (this->_GUI_MODE){
                 QMessageBox::warning(0, QObject::tr("Error"), message);
-                break;
-   case false:
+            } else {
                 Qcout<<QObject::tr("Error")<<endl<<message<<endl;
-                break;
             }
             return;
         }
@@ -1629,9 +1457,13 @@ QStringList corelib::getCdromDevices(void) const{
 
         void corelib::openHelpUrl(const QString rawurl){
             QString url="http://";
+            QString lang = this->getLang();
+            if (lang.contains("q4wine_")){
+                lang = lang.mid(7, -1);
+            }
             url.append(APP_WEBSITE);
             url.append("/documentation/");
-            url.append(this->getLang());
+            url.append(lang);
             url.append("/");
             url.append(rawurl);
 
@@ -1719,7 +1551,8 @@ QStringList corelib::getCdromDevices(void) const{
                     QStringList sh_args;
                     sh_args << "env";
                     sh_args << QString("WINEPREFIX=%1").arg(prefix_info.value("path"));
-                    sh_args << QString("WINEDLLPATH=%1").arg(prefix_info.value("libs"));
+                    if (!prefix_info.value("libs").isEmpty())
+                        sh_args << QString("WINEDLLPATH=%1").arg(prefix_info.value("libs"));
                     sh_args << QString("WINELOADER=%1").arg(prefix_info.value("loader"));
                     sh_args << QString("WINESERVER=%1").arg(prefix_info.value("server"));
                     if (!prefix_info.value("arch").isEmpty())
