@@ -138,11 +138,11 @@ public:
 
     void checkSettings(void);
 
-    QIcon loadIcon(QString iconName);
+    QIcon loadIcon(QString iconName, bool fromTheme = true);
     QPixmap loadPixmap(QString pixmapName);
 
     QString getTranslationLang();
-    QString getLang();
+    QString getLang(bool fromSettings = true);
     QString getLocale();
 
     bool isConfigured();
@@ -160,7 +160,6 @@ public:
      * \return Return the full path of binary.
      */
     QString getWhichOut (const QString fileName, bool showErr = true);
-    QStringList getWineLibsPath(void);
 
     /*! \brief This function get cdrom devices from /etc/fstab file.
      *
